# Novelsave Sources

A collection of webnovel sources offering varying amounts of scraping capability.

## Sources

> Request a new source by [creating a new issue](https://github.com/mHaisham/novelsave/issues/new/choose)

### Novel

| Sources                         | Login |                 Reason                  |
| ------------------------------- | :---: | :--: |
| [webnovel.com]                  |  ✔   |  |
| [wuxiaworld.co]                 |      |  |
| [boxnovel.com]                  |      |  |
| [readlightnovel.org]            |      |  |
| [insanitycave.poetry]           |      |  |
| [ktlchamber.wordpress]          |      |  |
| [kieshitl.wordpress]            |      |  |
| [scribblehub.com]               |      |  |
| [mtlnovel.com]                  |      |  |
| ~~[fanfiction.net]~~            |      | Broken due to cloudflare bot protection |
| [novelfull.com]                 |      |  |
| [wuxiaworld.com]                |      |  |
| [royalroad.com]                 |      |  |
| [wattpad.com]                   |      |  |
| [forums.spacebattles.com]       |      |  |
| [forums.sufficientvelocity.com] |      |  |
| [dragontea.ink]                 |      |  |
| [novelsite.net]                 |      |  |
| [foxaholic.com]                 |      |  |
| [chrysanthemumgarden.com]       |      |  |
| [peachpitting.com]              |      |  |
| [betwixtedbutterfly.com]        |      |  |
| [dummynovels.com]               |      |  |
| [chickengege.org]               |      |  |
| [wuxiaworld.online]             |      |  |
| [novelonlinefull.com]           |      |  |
| [novelpassion.com]              |      |  |
| [novelfun.net]                  |      |  |
| [novelhall.com]                 |      |  |
| [novelsrock.com]                |      |  |
| [creativenovels.com]            |      |  |
| [wuxiaworld.site]               |      |  |
| [novelgate.net]                 |      |  |
| [rainofsnow.com]                |      |  |

<!-- SOURCE LINKS -->

[webnovel.com]: https://www.webnovel.com
[wuxiaworld.co]: https://www.wuxiaworld.co
[boxnovel.com]: https://www.boxnovel.co
[readlightnovel.org]: https://www.readlightnovel.org
[insanitycave.poetry]: https://insanitycave.poetry.blog
[ktlchamber.wordpress]: https://ktlchamber.wordpress.com
[kieshitl.wordpress]: https://kieshitl.wordpress.com
[scribblehub.com]: https://www.scribblehub.com
[mtlnovel.com]: https://www.mtlnovel.com
[fanfiction.net]: https://www.fanfiction.net
[novelfull.com]: https://novelfull.com
[wuxiaworld.com]: https://www.wuxiaworld.com
[royalroad.com]: https://www.royalroad.com
[wattpad.com]: https://www.wattpad.com
[forums.spacebattles.com]: https://forums.spacebattles.com
[forums.sufficientvelocity.com]: https://forums.sufficientvelocity.com
[dragontea.ink]: https://dragontea.ink
[novelsite.net]: https://novelsite.net
[foxaholic.com]: https://foxaholic.com
[chrysanthemumgarden.com]: https://chrysanthemumgarden.com
[peachpitting.com]: https://peachpitting.com
[betwixtedbutterfly.com]: https://betwixtedbutterfly.com
[dummynovels.com]: https://dummynovels.com
[chickengege.org]: https://www.chickengege.org
[wuxiaworld.online]: https://wuxiaworld.online
[novelonlinefull.com]: https://novelonlinefull.com
[novelpassion.com]: https://www.novelpassion.com
[novelfun.net]: https://novelfun.net
[novelhall.com]: https://www.novelhall.com
[novelsrock.com]: https://novelsrock.com
[creativenovels.com]: https://creativenovels.com
[wuxiaworld.site]: https://wuxiaworld.site
[novelgate.net]: https://novelgate.net
[rainofsnow.com]: https://rainofsnow.com

### Metadata

| Metadata Source |
| -- | :--: |
| [wlnupdates.com] |
| [novelupdates.com] |

<!-- META SOURCE LINKS -->

[wlnupdates.com]: https://www.wlnupdates.com
[novelupdates.com]: https://www.novelupdates.com

## Disclaimer

We are not affiliated, associated, authorized, endorsed by, or in any way officially connected with the any of the [sources](#sources) mentioned above.

## License

[Apache-2.0](https://github.com/mHaisham/novelsave_sources/blob/master/LICENSE)